Changelog
=========

v0.1.6
------

- Added support for showing more information:

  - record date
  - file name / line number
  - module / function

v0.1.5
------

- Added support for nicer colors in 256-color mode
- Removed dependency from termcolor (now shipping better implementation)
